import 'package:flutter/material.dart';
import 'package:libcli/log/log.dart' as log;
import 'package:libcli/log/color.dart';

const here = 'async/await';

enum AsyncStatus { wait, ready, error }

abstract class AsyncProvider with ChangeNotifier {
  AsyncStatus asyncStatus = AsyncStatus.wait;

  /// prevent notifyListeners after dispose
  bool _disposed = false;

  /// load happen when object created
  ///
  Future<void> load() async {}

  @override
  notifyListeners() {
    if (!_disposed) {
      super.notifyListeners();
    }
  }

  @override
  void dispose() {
    log.debug(here, 'dispose $runtimeType');
    _disposed = true;
    super.dispose();
  }
}
