import 'dart:async';
import 'package:libui/async/async_provider.dart';
import 'package:libui/i18n/i18n_model.dart';
import 'package:libui/i18n/i18n.dart' as i18n;
import 'package:libcli/log/log.dart' as log;
import 'package:libcli/log/color.dart';

class I18nProvider extends AsyncProvider {
  final String pageName;

  final I18nModel model;

  I18nProvider(this.pageName, this.model);

/*

  static I18nController of(BuildContext context) {
    return Localizations.of<I18nController>(context, I18nController);
  }
*/

  @override
  Future<void> load() async {
    assert(i18n.localeID.length > 0,
        "need I18nDelegate to localizationsDelegates");

    await model.read(pageName, i18n.localeID);
  }

  String translate(String key) {
    assert(model.state != null, 'load localzation before translate');
    var value = model.state.translate(key);
    if (value == null) {
      log.alert('i18n', 'missing "$key" in ${pageName}_${i18n.localeID}');
      return '!!! $key not found';
    }
    return value;
  }
}
